==> spip_3.0.8.orig.tar.xz: spip-3.0.8.orig/plugins-dist/sites/lang/sites_fr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://zone.spip.org/spip-zone/_core_/plugins/sites/lang/
if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'En attente',
	'articles_meme_auteur' => 'Tous les articles de cet auteur',
	'articles_off' => 'Bloqués',
	'articles_publie' => 'Publiés',
	'articles_refuse' => 'Supprimés',
	'articles_tous' => 'Tous',
	'aucun_article_syndic' => 'Aucun article syndiqué',
	'avis_echec_syndication_01' => 'La syndication a échoué : le backend indiqué est indéchiffrable ou ne propose aucun article.',
	'avis_echec_syndication_02' => 'La syndication a échoué : impossible d\'accéder au backend de ce site.',
	'avis_site_introuvable' => 'Site introuvable',
	'avis_site_syndique_probleme' => 'Attention : la syndication de ce site a rencontré un problème ; le système est donc temporairement interrompu. Vérifiez l\'adresse du fichier de syndication de ce site (<b>@url_syndic@</b>), et tentez une nouvelle récupération des informations.',
	'avis_sites_probleme_syndication' => 'Ces sites ont rencontré un problème de syndication',
	'avis_sites_syndiques_probleme' => 'Ces sites syndiqués ont posé un problème',

	// B
	'bouton_exporter' => 'Exporter',
	'bouton_importer' => 'Importer',
	'bouton_radio_modere_posteriori' => 'modération a posteriori',
	'bouton_radio_modere_priori' => 'modération a priori',
	'bouton_radio_non_syndication' => 'Pas de syndication',
	'bouton_radio_syndication' => 'Syndication :',

	// C
	'confirmer_purger_syndication' => 'Êtes-vous certain de vouloir supprimer tous les articles syndiqués de ce site ?',

	// E
	'entree_adresse_fichier_syndication' => 'Adresse du fichier de syndication :',
	'entree_adresse_site' => '<b>Adresse du site</b> [Obligatoire]',
	'entree_description_site' => 'Description du site',
	'erreur_fichier_format_inconnu' => 'Le format du fichier @fichier@ n\'est pas pris en charge.',
	'erreur_fichier_incorrect' => 'Impossible de lire le fichier.',

	// F
	'form_prop_nom_site' => 'Nom du site',

	// I
	'icone_article_syndic' => 'Article syndiqué',
	'icone_articles_syndic' => 'Articles syndiqués',
	'icone_controler_syndication' => 'Publication des articles syndiqués',
	'icone_modifier_site' => 'Modifier ce site',
	'icone_referencer_nouveau_site' => 'Référencer un nouveau site',
	'icone_site_reference' => 'Sites référencés',
	'icone_supprimer_article' => 'Supprimer cet article',
	'icone_supprimer_articles' => 'Supprimer ces articles',
	'icone_valider_article' => 'Valider cet article',
	'icone_valider_articles' => 'Valider ces articles',
	'icone_voir_sites_references' => 'Voir les sites référencés',
	'info_1_site_importe' => '1 site a été importé',
	'info_a_valider' => '[à valider]',
	'info_aucun_site_importe' => 'Aucun site n\'a pu être importé',
	'info_bloquer' => 'bloquer',
	'info_bloquer_lien' => 'bloquer ce lien',
	'info_derniere_syndication' => 'La dernière syndication de ce site a été effectuée le',
	'info_liens_syndiques_1' => 'liens syndiqués',
	'info_liens_syndiques_2' => 'sont en attente de validation.',
	'info_nb_sites_importes' => '@nb@ sites ont été importés',
	'info_nom_site_2' => '<b>Nom du site</b> [Obligatoire]',
	'info_panne_site_syndique' => 'Site syndiqué en panne',
	'info_probleme_grave' => 'problème de',
	'info_question_proposer_site' => 'Qui peut proposer des sites référencés ?',
	'info_retablir_lien' => 'rétablir ce lien',
	'info_site_attente' => 'Site Web en attente de validation',
	'info_site_propose' => 'Site proposé le :',
	'info_site_reference' => 'Site référencé en ligne',
	'info_site_refuse' => 'Site Web refusé',
	'info_site_syndique' => 'Ce site est syndiqué…',
	'info_site_valider' => 'Sites à valider',
	'info_sites_referencer' => 'Référencer un site',
	'info_sites_refuses' => 'Les sites refusés',
	'info_statut_site_1' => 'Ce site est :',
	'info_statut_site_2' => 'Publié',
	'info_statut_site_3' => 'Proposé',
	'info_statut_site_4' => 'À la poubelle',
	'info_syndication' => 'syndication :',
	'info_syndication_articles' => 'article(s)',
	'item_bloquer_liens_syndiques' => 'Bloquer les liens syndiqués pour validation',
	'item_gerer_annuaire_site_web' => 'Gérer un annuaire de sites Web',
	'item_non_bloquer_liens_syndiques' => 'Ne pas bloquer les liens issus de la syndication',
	'item_non_gerer_annuaire_site_web' => 'Désactiver l\'annuaire de sites Web',
	'item_non_utiliser_syndication' => 'Ne pas utiliser la syndication automatique',
	'item_utiliser_syndication' => 'Utiliser la syndication automatique',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exporter les mots-clés sous forme de tags',
	'label_exporter_id_parent' => 'Exporter les sites de la rubrique',
	'label_exporter_publie_seulement_1' => 'Exporter uniquement les sites publiés',
	'label_fichier_import' => 'Fichier HTML',
	'label_importer_les_tags_1' => 'Importer les tags sous forme de mots-clés',
	'label_importer_statut_publie_1' => 'Publier automatiquement les sites',
	'lien_mise_a_jour_syndication' => 'Mettre à jour maintenant',
	'lien_nouvelle_recuperation' => 'Tenter une nouvelle récupération des données',
	'lien_purger_syndication' => 'Effacer tous les articles syndiqués',

	// N
	'nombre_articles_syndic' => '@nb@ articles syndiqués',

	// S
	'statut_off' => 'Supprimé',
	'statut_prop' => 'En attente',
	'statut_publie' => 'Publié',
	'syndic_choix_moderation' => 'Que faire des prochains liens en provenance de ce site ?',
	'syndic_choix_oublier' => 'Que faire des liens qui ne figurent plus dans le fichier de syndication ?',
	'syndic_choix_resume' => 'Certains sites diffusent le texte complet des articles. Lorsque celui-ci est disponible souhaitez-vous syndiquer :',
	'syndic_lien_obsolete' => 'lien obsolète',
	'syndic_option_miroir' => 'les bloquer automatiquement',
	'syndic_option_oubli' => 'les effacer (après @mois@ mois)',
	'syndic_option_resume_non' => 'le contenu complet des articles (au format HTML)',
	'syndic_option_resume_oui' => 'un simple résumé (au format texte)',
	'syndic_options' => 'Options de syndication :',

	// T
	'texte_expliquer_export_bookmarks' => 'Vous pouvez exporter une liste de sites au format Marque-page HTML,
	pour vous permettre ensuite de l\'importer dans votre navigateur ou dans un service en ligne',
	'texte_expliquer_import_bookmarks' => 'Vous pouvez importer une liste de sites au format Marque-page HTML,
	en provenance de votre navigateur ou d\'un service en ligne de gestion des Marques-pages.',
	'texte_liens_sites_syndiques' => 'Les liens issus des sites syndiqués peuvent être bloqués a priori ; le réglage ci-dessous indique le réglage par défaut des sites syndiqués après leur création. Il est ensuite possible de débloquer chaque lien individuellement ou de choisir, site par site, de bloquer les liens à venir de tel ou tel site.',
	'texte_messages_publics' => 'Messages publics de l\'article :',
	'texte_non_fonction_referencement' => 'Vous pouvez préférer ne pas utiliser cette fonction automatique, et indiquer vous-même les éléments concernant ce site…',
	'texte_referencement_automatique' => '<b>Référencement automatisé d\'un site</b><br />Vous pouvez référencer rapidement un site Web en indiquant ci-dessous l\'adresse URL désirée, ou l\'adresse de son fichier de syndication. SPIP va récupérer automatiquement les informations concernant ce site (titre, description…).',
	'texte_referencement_automatique_verifier' => 'Veuillez vérifier les informations fournies par <tt>@url@</tt> avant d\'enregistrer.',
	'texte_syndication' => 'Il est possible de récupérer automatiquement, lorsqu\'un site Web le permet, la liste de ses nouveautés. Pour cela, vous devez activer la syndication.
	<blockquote><i>Certains hébergeurs désactivent cette fonctionnalité ; dans ce cas, vous ne pourrez pas utiliser la syndication de contenu depuis votre site.</i></blockquote>',
	'titre_articles_syndiques' => 'Articles syndiqués tirés de ce site',
	'titre_dernier_article_syndique' => 'Derniers articles syndiqués',
	'titre_exporter_bookmarks' => 'Exporter des Marques-pages',
	'titre_importer_bookmarks' => 'Importer des Marques-pages',
	'titre_importer_exporter_bookmarks' => 'Importer et Exporter des Marques-pages',
	'titre_page_sites_tous' => 'Les sites référencés',
	'titre_referencement_sites' => 'Référencement de sites et syndication',
	'titre_site_numero' => 'SITE NUMÉRO :',
	'titre_sites_proposes' => 'Les sites proposés',
	'titre_sites_references_rubrique' => 'Les sites référencés dans cette rubrique',
	'titre_sites_syndiques' => 'Les sites syndiqués',
	'titre_sites_tous' => 'Les sites référencés',
	'titre_syndication' => 'Syndication de sites',
	'tout_voir' => 'Voir tous les articles syndiqués',

	// U
	'un_article_syndic' => '1 article syndiqué'
);

?>

==> spip_3.1~21100.orig.tar.xz: spip-3.1~21100.orig/plugins-dist/sites/lang/sites_fr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://zone.spip.org/spip-zone/_core_/plugins/sites/lang/
if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'articles_dispo' => 'En attente',
	'articles_meme_auteur' => 'Tous les articles de cet auteur',
	'articles_off' => 'Bloqués',
	'articles_publie' => 'Publiés',
	'articles_refuse' => 'Supprimés',
	'articles_tous' => 'Tous',
	'aucun_article_syndic' => 'Aucun article syndiqué',
	'avis_echec_syndication_01' => 'La syndication a échoué : le backend indiqué est indéchiffrable ou ne propose aucun article.',
	'avis_echec_syndication_02' => 'La syndication a échoué : impossible d’accéder au backend de ce site.',
	'avis_site_introuvable' => 'Site introuvable',
	'avis_site_syndique_probleme' => 'Attention : la syndication de ce site a rencontré un problème ; le système est donc temporairement interrompu. Vérifiez l’adresse du fichier de syndication de ce site (<b>@url_syndic@</b>), et tentez une nouvelle récupération des informations.',
	'avis_sites_probleme_syndication' => 'Ces sites ont rencontré un problème de syndication',
	'avis_sites_syndiques_probleme' => 'Ces sites syndiqués ont posé un problème',

	// B
	'bouton_exporter' => 'Exporter',
	'bouton_importer' => 'Importer',
	'bouton_radio_modere_posteriori' => 'modération a posteriori',
	'bouton_radio_modere_priori' => 'modération a priori',
	'bouton_radio_non_syndication' => 'Pas de syndication',
	'bouton_radio_syndication' => 'Syndication :',

	// C
	'confirmer_purger_syndication' => 'Êtes-vous certain de vouloir supprimer tous les articles syndiqués de ce site ?',

	// E
	'entree_adresse_fichier_syndication' => 'Adresse du fichier de syndication :',
	'entree_adresse_site' => '<b>Adresse du site</b> [Obligatoire]',
	'entree_description_site' => 'Description du site',
	'erreur_fichier_format_inconnu' => 'Le format du fichier @fichier@ n’est pas pris en charge.',
	'erreur_fichier_incorrect' => 'Impossible de lire le fichier.',

	// F
	'form_prop_nom_site' => 'Nom du site',

	// I
	'icone_article_syndic' => 'Article syndiqué',
	'icone_articles_syndic' => 'Articles syndiqués',
	'icone_controler_syndication' => 'Publication des articles syndiqués',
	'icone_modifier_site' => 'Modifier ce site',
	'icone_referencer_nouveau_site' => 'Référencer un nouveau site',
	'icone_site_reference' => 'Sites référencés',
	'icone_supprimer_article' => 'Supprimer cet article',
	'icone_supprimer_articles' => 'Supprimer ces articles',
	'icone_valider_article' => 'Valider cet article',
	'icone_valider_articles' => 'Valider ces articles',
	'icone_voir_sites_references' => 'Voir les sites référencés',
	'info_1_article_syndique' => '1 article syndiqué',
	'info_1_site' => '1 site',
	'info_1_site_importe' => '1 site a été importé',
	'info_a_valider' => '[à valider]',
	'info_aucun_article_syndique' => 'Aucun article syndiqué',
	'info_aucun_site' => 'Aucun site',
	'info_aucun_site_importe' => 'Aucun site n’a pu être importé',
	'info_bloquer' => 'bloquer',
	'info_bloquer_lien' => 'bloquer ce lien',
	'info_derniere_syndication' => 'La dernière syndication de ce site a été effectuée le',
	'info_liens_syndiques_1' => 'liens syndiqués',
	'info_liens_syndiques_2' => 'sont en attente de validation.',
	'info_nb_articles_syndiques' => '@nb@ articles syndiqués',
	'info_nb_sites' => '@nb@ sites',
	'info_nb_sites_importes' => '@nb@ sites ont été importés',
	'info_nom_site_2' => '<b>Nom du site</b> [Obligatoire]',
	'info_panne_site_syndique' => 'Site syndiqué en panne',
	'info_probleme_grave' => 'problème de',
	'info_question_proposer_site' => 'Qui peut proposer des sites référencés ?',
	'info_retablir_lien' => 'rétablir ce lien',
	'info_site_attente' => 'Site Web en attente de validation',
	'info_site_propose' => 'Site proposé le :',
	'info_site_reference' => 'Site référencé en ligne',
	'info_site_refuse' => 'Site Web refusé',
	'info_site_syndique' => 'Ce site est syndiqué…',
	'info_site_valider' => 'Sites à valider',
	'info_sites_referencer' => 'Référencer un site',
	'info_sites_refuses' => 'Les sites refusés',
	'info_statut_site_1' => 'Ce site est :',
	'info_statut_site_2' => 'Publié',
	'info_statut_site_3' => 'Proposé',
	'info_statut_site_4' => 'À la poubelle',
	'info_syndication' => 'syndication :',
	'info_syndication_articles' => 'article(s)',
	'item_bloquer_liens_syndiques' => 'Bloquer les liens syndiqués pour validation',
	'item_gerer_annuaire_site_web' => 'Gérer un annuaire de sites Web',
	'item_non_bloquer_liens_syndiques' => 'Ne pas bloquer les liens issus de la syndication',
	'item_non_gerer_annuaire_site_web' => 'Désactiver l’annuaire de sites Web',
	'item_non_utiliser_syndication' => 'Ne pas utiliser la syndication automatique',
	'item_utiliser_syndication' => 'Utiliser la syndication automatique',

	// L
	'label_exporter_avec_mots_cles_1' => 'Exporter les mots-clés sous forme de tags',
	'label_exporter_id_parent' => 'Exporter les sites de la rubrique',
	'label_exporter_publie_seulement_1' => 'Exporter uniquement les sites publiés',
	'label_fichier_import' => 'Fichier HTML',
	'label_importer_les_tags_1' => 'Importer les tags sous forme de mots-clés',
	'label_importer_statut_publie_1' => 'Publier automatiquement les sites',
	'lien_mise_a_jour_syndication' => 'Mettre à jour maintenant',
	'lien_nouvelle_recuperation' => 'Tenter une nouvelle récupération des données',
	'lien_purger_syndication' => 'Effacer tous les articles syndiqués',

	// N
	'nombre_articles_syndic' => '@nb@ articles syndiqués',

	// S
	'statut_off' => 'Supprimé',
	'statut_prop' => 'En attente',
	'statut_publie' => 'Publié',
	'syndic_choix_moderation' => 'Que faire des prochains liens en provenance de ce site ?',
	'syndic_choix_oublier' => 'Que faire des liens qui ne figurent plus dans le fichier de syndication ?',
	'syndic_choix_resume' => 'Certains sites diffusent le texte complet des articles. Lorsque celui-ci est disponible souhaitez-vous syndiquer :',
	'syndic_lien_obsolete' => 'lien obsolète',
	'syndic_option_miroir' => 'les bloquer automatiquement',
	'syndic_option_oubli' => 'les effacer (après @mois@ mois)',
	'syndic_option_resume_non' => 'le contenu complet des articles (au format HTML)',
	'syndic_option_resume_oui' => 'un simple résumé (au format texte)',
	'syndic_options' => 'Options de syndication :',

	// T
	'texte_expliquer_export_bookmarks' => 'Vous pouvez exporter une liste de sites au format Marque-page HTML,
	pour vous permettre ensuite de l’importer dans votre navigateur ou dans un service en ligne',
	'texte_expliquer_import_bookmarks' => 'Vous pouvez importer une liste de sites au format Marque-page HTML,
	en provenance de votre navigateur ou d’un service en ligne de gestion des Marques-pages.',
	'texte_liens_sites_syndiques' => 'Les liens issus des sites syndiqués peuvent être bloqués a priori ; le réglage ci-dessous indique le réglage par défaut des sites syndiqués après leur création. Il est ensuite possible de débloquer chaque lien individuellement ou de choisir, site par site, de bloquer les liens à venir de tel ou tel site.',
	'texte_messages_publics' => 'Messages publics de l’article :',
	'texte_non_fonction_referencement' => 'Vous pouvez préférer ne pas utiliser cette fonction automatique, et indiquer vous-même les éléments concernant ce site…',
	'texte_referencement_automatique' => '<b>Référencement automatisé d’un site</b><br />Vous pouvez référencer rapidement un site Web en indiquant ci-dessous l’adresse URL désirée, ou l’adresse de son fichier de syndication. SPIP va récupérer automatiquement les informations concernant ce site (titre, description…).',
	'texte_referencement_automatique_verifier' => 'Veuillez vérifier les informations fournies par <tt>@url@</tt> avant d’enregistrer.',
	'texte_syndication' => 'Il est possible de récupérer automatiquement, lorsqu’un site Web le permet, la liste de ses nouveautés. Pour cela, vous devez activer la syndication.
	<blockquote><i>Certains hébergeurs désactivent cette fonctionnalité ; dans ce cas, vous ne pourrez pas utiliser la syndication de contenu depuis votre site.</i></blockquote>',
	'titre_articles_syndiques' => 'Articles syndiqués tirés de ce site',
	'titre_dernier_article_syndique' => 'Derniers articles syndiqués',
	'titre_exporter_bookmarks' => 'Exporter des Marques-pages',
	'titre_importer_bookmarks' => 'Importer des Marques-pages',
	'titre_importer_exporter_bookmarks' => 'Importer et Exporter des Marques-pages',
	'titre_page_sites_tous' => 'Les sites référencés',
	'titre_referencement_sites' => 'Référencement de sites et syndication',
	'titre_site_numero' => 'SITE NUMÉRO :',
	'titre_sites_proposes' => 'Les sites proposés',
	'titre_sites_references_rubrique' => 'Les sites référencés dans cette rubrique',
	'titre_sites_syndiques' => 'Les sites syndiqués',
	'titre_sites_tous' => 'Les sites référencés',
	'titre_syndication' => 'Syndication de sites',
	'tout_voir' => 'Voir tous les articles syndiqués',

	// U
	'un_article_syndic' => '1 article syndiqué'
);

?>
